#!/usr/bin/env python3
"""
Someone's Mattermost API v4 bindings.
  Copyright (c) 2016-2021 by Someone <someone@somenet.org> (aka. Jan Vales <jan@jvales.net>)
  published under MIT-License
"""

# Set this package's version.
__version__ = "5.31.0"



#!/usr/bin/env python3
"""
Someone's Mattermost API v4 bindings.
  Copyright (c) 2016-2021 by Someone <someone@somenet.org> (aka. Jan Vales <jan@jvales.net>)
  published under MIT-License
"""

import logging
import json
import asyncio
import threading
import traceback
import websockets

logger = logging.getLogger("mattermost.ws")


class MMws:
    """
    Websocket client.
    """

    def __init__(self, ws_handler, api, ws_url):
        self.api = api
        self.ws_url = ws_url
        self.ws_handler = ws_handler
        self.loop = asyncio.new_event_loop()

        self._new_websocket_thread()


    def close_websocket(self):
        """
        Close the websocket and invalidate this object.
        """
        self.loop.stop()
        self.loop = None


    def _new_websocket_thread(self):
        if self.loop is None:
            return

        thread = threading.Timer(3.0, self._open_websocket)
        thread.setDaemon(True)
        thread.setName("websocket")
        thread.start()


    def _open_websocket(self):
        try:
            self.loop.run_until_complete(self._websocket_run())
        except:
            if self.loop:
                logger.info("websocket failed. restarting...")
                logger.error("".join(traceback.format_exc()))

        self._new_websocket_thread()


    async def _websocket_run(self):
        logger.info("Starting websocket client.")
        async with websockets.connect(self.ws_url) as websocket:
            await websocket.send(json.dumps({"seq": 1, "action":"authentication_challenge", "data":{"token":self.api._bearer}}))
            logger.info("websocket client connected")

            while self.loop:
                data = json.loads(await websocket.recv())
                if "event" not in data:
                    continue

                try:
                    self.ws_handler(self, data)
                except:
                    logger.error("".join(traceback.format_exc()))



#!/usr/bin/env python3
"""
Someone's Mattermost API v4 bindings.
  Copyright (c) 2016-2021 by Someone <someone@somenet.org> (aka. Jan Vales <jan@jvales.net>)
  published under MIT-License

post stdin to a channel.
"""

import os
import sys

from inspect import cleandoc

import mattermost


def main():
    show_usage = False
    mm_api = None
    chan_id = None

    if "MM_APIURL" in os.environ:
        mm_api = mattermost.MMApi(os.environ["MM_APIURL"])
    else:
        show_usage = True


    if ("MM_USER" in os.environ and "MM_PASS" in os.environ) or ("MM_BEARER" in os.environ):
        if "MM_BEARER" in os.environ:
            mm_api.login(bearer=os.environ["MM_BEARER"])
        else:
            mm_api.login(os.environ["MM_USER"], os.environ["MM_PASS"])
    else:
        show_usage = True


    if "MM_CHANID" in os.environ:
        chan_id = os.environ["MM_CHANID"]
    else:
        show_usage = True


    if len(sys.argv) < 1 or len(sys.argv) > 3:
        show_usage = True


    if show_usage:
        print(cleandoc("""required ENV-parameters: MM_APIURL, MM_USER+MM_PASS or MM_BEARER, MM_CHANID.
            arguments: [PREFIX] [SUFFIX]
            """))
        sys.exit(1)


    prefix = suffix = ""
    try:
        prefix = sys.argv[1].replace("\\n", "\n")
        suffix = sys.argv[2].replace("\\n", "\n")
    except:
        pass

    print("Posting to channel:" +str(mm_api.create_post(chan_id, prefix+sys.stdin.read()+suffix, props={"from_webhook":"true"})))

    mm_api.logout()


if __name__ == '__main__':
    main()
